@@ -10,7 +10,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict
+from typing import IO, Any, Dict, Union
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -32,7 +32,7 @@ ResponseMetadata = TypedDict(
 )
 
 _RequiredInvokeEndpointOutputTypeDef = TypedDict(
-    "_RequiredInvokeEndpointOutputTypeDef", {"Body": bytes}
+    "_RequiredInvokeEndpointOutputTypeDef", {"Body": Union[bytes, IO[bytes]]}
 )
 _OptionalInvokeEndpointOutputTypeDef = TypedDict(
     "_OptionalInvokeEndpointOutputTypeDef",
